@@ -5,5 +5,5 @@ from holour.msg.script import Script, WaypointConfig
 from holour.msg.task import Task
 from holour.msg.product import Product
 from holour.msg.process import Process
-from holour.msg.assembly import AddProcess, MoveTask, CompleteTask, Destination, ConfirmNeeded, ConfirmTask
+from holour.msg.assembly import AddProcess, MoveTask, CompleteTask, Destination, ConfirmNeeded, ConfirmTask, TaskStatus
 from holour.msg.robot import ProgramState
