@@ -13,7 +13,8 @@ class Test(TestCase):
         expected_string = '{"_type": "task", "uuid": "uuid", "name": "name", "product_uuid": "product_uuid", ' \
                           '"pose": {"_type": "pose", "name": "", "position": {"_type": "vector3", "x": 0.0, ' \
                           '"y": 0.0, "z": 0.0}, "rotation": {"_type": "vector3", "x": 0.0, "y": 0.0, "z": 0.0}}, ' \
-                          '"automated": false, "conditions": [], "conditions_fulfilled": true, "description": ""}'
+                          '"automated": false, "conditions": [], "conditions_fulfilled": true, "description": "", ' \
+                          '"status": "waiting"}'
 
         self.assertIs(type(task_string), str, f"Got: {type(task_string)}. Expected {str}")
         self.assertEqual(task_string, expected_string, f"Expected {expected_string}, got: {task_string}")
